var languageNames = {
"en-US": "Inglés (EXA)",
"am": "Amáricu",
"ar": "Árabe",
"ast": "Asturianu",
"bg": "Búlgaru",
"bn": "Bengalín",
"bn-IN": "Bengalín (India)",
"bo": "Tibetanu",
"bs": "Bosniu",
"ca": "Catalán",
"ca-valencia": "Catalán (valencianu)",
"cs": "Checu",
"da": "Danés",
"de": "Alemán",
"dz": "Butanés",
"el": "Griegu",
"en-GB": "Inglés (RX)",
"en-ZA": "Inglés (Sudáf.)",
"eo": "Esperantu",
"es": "Spanish",
"et": "Estonian",
"eu": "Vascu",
"fi": "Finnish",
"fr": "French",
"gl": "Gallegu",
"gu": "Gujarati",
"he": "Hebréu",
"hi": "Hindi",
"hr": "Croatian",
"hu": "Hungarian",
"id": "Indonesian",
"is": "Icelandic",
"it": "Italian",
"ja": "Japanese",
"ka": "Georgian",
"km": "Ḥemer",
"ko": "Korean",
"lo": "Lao",
"lt": "Lithuanian",
"lv": "Latvian",
"mk": "Macedonian",
"nb": "Norwegian Bokmål",
"ne": "Nepali",
"nl": "Dutch",
"nn": "Norwegian Nynorsk",
"om": "Oromo",
"pl": "Polish",
"pt": "Portuguese",
"pt-BR": "Portugués (brasilanu)",
"ro": "Romanian",
"ru": "Russian",
"si": "Sinhala",
"sid": "Sidama",
"sk": "Slovak",
"sl": "Slovenian",
"sq": "Albanian",
"sv": "Swedish",
"ta": "Tamil",
"tg": "Tajik",
"tr": "Turkish",
"ug": "Uyghur",
"uk": "Ucraín",
"vi": "Vietnamese",
"zh-CN": "Chinu (simplificáu)",
"zh-TW": "Chinu (tradicional)",
};
